@@ -1,5 +1,7 @@
 '''A simple QoL module to make doing repetitive pwn easier'''
 from pwn import *
+from pwnscripts.context import context	# Keep this at top-level
+from pwnscripts.elf import *
 from pwnscripts.string_checks import *
 from pwnscripts.libcdb_query import *
 from pwnscripts.uncommon import *
